<?php
/**
 * Localization Tab
 *
 * @package Buy Again\Settings Tab
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( class_exists( 'BYA_Localization_Tab' ) ) {
	return new BYA_Localization_Tab();
}

/**
 * BYA_Localization_Tab.
 */
class BYA_Localization_Tab extends BYA_Settings_Page {

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->id    = 'localization';
		$this->label = esc_html__( 'Localization', 'buy-again-for-woocommerce' );

		parent::__construct();
	}

	/**
	 * Get sections.
	 */
	public function get_sections() {
		$sections = array();
		/**
		 * Filter to Buy Again Settings section.
		 *
		 * @since 1.0
		 * */
		return apply_filters( $this->plugin_slug . '_get_sections_' . $this->id, $sections );
	}

	/**
	 * Get settings for localization section array.
	 */
	public function localization_section_array() {
		$section_fields = array();

		// Localization Section Start.
		$section_fields[] = array(
			'type'  => 'title',
			'title' => esc_html__( 'Localization', 'buy-again-for-woocommerce' ),
			'id'    => 'bya_localization_options',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Buy Again My Account Page Label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Buy Again',
			'id'      => $this->get_option_key( 'buy_again_menu_label' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'             => esc_html__( 'No.Of Products to Display Per Page in Buy Again Table', 'buy-again-for-woocommerce' ),
			'type'              => 'number',
			'default'           => '5',
			'custom_attributes' => array( 'min' => '1' ),
			'id'                => $this->get_option_key( 'myaccount_per_page_product_count' ),
			'class'             => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Search Field Label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Search Products',
			'id'      => $this->get_option_key( 'search_field_label' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Display Product Thumbnail in Buy Again Table', 'buy-again-for-woocommerce' ),
			'type'    => 'checkbox',
			'default' => 'yes',
			'id'      => $this->get_option_key( 'allow_product_image_col' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Product Thumbnail Column Label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Product Image',
			'id'      => $this->get_option_key( 'product_image_label' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Display Product Title Column', 'buy-again-for-woocommerce' ),
			'type'    => 'checkbox',
			'default' => 'yes',
			'id'      => $this->get_option_key( 'allow_product_name_col' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Product Title Column Label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Product Name',
			'id'      => $this->get_option_key( 'product_name_label' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Product Description', 'buy-again-for-woocommerce' ),
			'type'    => 'select',
			'options' => array(
				'1' => esc_html__( 'Show', 'buy-again-for-woocommerce' ),
				'2' => esc_html__( 'Hide', 'buy-again-for-woocommerce' ),
			),
			'default' => '2',
			'id'      => $this->get_option_key( 'buy_again_table_product_desc' ),
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Display Previously purchased quantity count & order count Column', 'buy-again-for-woocommerce' ),
			'type'    => 'checkbox',
			'default' => 'no',
			'id'      => $this->get_option_key( 'allow_order_count_col' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Previously purchased quantity count & order count label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Purchased quantity & order count',
			'id'      => $this->get_option_key( 'order_count_label' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Previously purchased quantity count & order count', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => '[qty_count] quantity of [order_count] order(s)',
			'id'      => $this->get_option_key( 'order_count_val' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Display Last purchased order column in Buy Again Table', 'buy-again-for-woocommerce' ),
			'type'    => 'checkbox',
			'default' => 'yes',
			'id'      => $this->get_option_key( 'allow_last_purchased_order_id_col' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Last purchased order column label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Last Purchased Order',
			'id'      => $this->get_option_key( 'last_purchased_order_id_label' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Product Price Column', 'buy-again-for-woocommerce' ),
			'type'    => 'checkbox',
			'default' => 'yes',
			'id'      => $this->get_option_key( 'allow_product_price_col' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Product Price Column Label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Product Price',
			'id'      => $this->get_option_key( 'product_price_label' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Product Quantity Column', 'buy-again-for-woocommerce' ),
			'type'    => 'checkbox',
			'default' => 'yes',
			'id'      => $this->get_option_key( 'allow_product_quantity_col' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Product Quantity Column Label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Product Quantity',
			'id'      => $this->get_option_key( 'product_quantity_label' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Action Column', 'buy-again-for-woocommerce' ),
			'type'    => 'checkbox',
			'default' => 'yes',
			'id'      => $this->get_option_key( 'allow_action_col' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Action Column Label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Action',
			'id'      => $this->get_option_key( 'action_label' ),
			'class'   => 'bya_myaccount_fields',
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Display Add to Cart Button', 'buy-again-for-woocommerce' ),
			'type'    => 'checkbox',
			'default' => 'yes',
			'id'      => $this->get_option_key( 'allow_add_to_cart_col' ),
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Add to Cart Button Label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Add to Cart',
			'id'      => $this->get_option_key( 'add_to_cart_label' ),
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Buy Now Button Label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Buy Now',
			'id'      => $this->get_option_key( 'buy_again_label' ),
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Filter Button Label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Filter',
			'id'      => $this->get_option_key( 'filter_btn_label' ),
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Filter By label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Filter By',
			'id'      => $this->get_option_key( 'filter_by_label' ),
		);
		$section_fields[] = array(
			'title'   => esc_html__( 'Search Button Label', 'buy-again-for-woocommerce' ),
			'type'    => 'text',
			'default' => 'Search',
			'id'      => $this->get_option_key( 'search_btn_label' ),
		);
		$section_fields[] = array(
			'type' => 'sectionend',
			'id'   => 'bya_localization_options',
		);
		// Localization Section End.

		return $section_fields;
	}

}

return new BYA_Localization_Tab();
